@@ -1,12 +1,12 @@
 /* gcompris - algebra.c
  *
- * Time-stamp: <2006/08/21 23:29:57 bruno>
+ * Time-stamp: <2007-08-22 01:27:17 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <ctype.h>
@@ -607,19 +606,19 @@ static GnomeCanvasItem *algebra_create_item(GnomeCanvasGroup *parent)
     {
     case PLUSSIGNFILE:
       expected_result = g_strdup_printf("%d", first_operand+second_operand);
-      audioOperand = "sounds/$LOCALE/misc/plus.ogg";
+      audioOperand = "voices/$LOCALE/misc/plus.ogg";
       break;
     case MINUSSIGNFILE:
       expected_result = g_strdup_printf("%d", first_operand-second_operand);
-      audioOperand = "sounds/$LOCALE/misc/minus.ogg";
+      audioOperand = "voices/$LOCALE/misc/minus.ogg";
       break;
     case BYSIGNFILE:
       expected_result = g_strdup_printf("%d", first_operand*second_operand);
-      audioOperand = "sounds/$LOCALE/misc/by.ogg";
+      audioOperand = "voices/$LOCALE/misc/by.ogg";
       break;
     case DIVIDESIGNFILE:
       expected_result = g_strdup_printf("%d", first_operand/second_operand);
-      audioOperand = "sounds/$LOCALE/misc/outof.ogg";
+      audioOperand = "voices/$LOCALE/misc/outof.ogg";
       break;
     default:
       g_error("Bad Operation");
@@ -646,10 +645,10 @@ static GnomeCanvasItem *algebra_create_item(GnomeCanvasGroup *parent)
     g_free(first_operand_str);
     g_free(second_operand_str);
 
-    first_operand_str = g_strdup_printf("sounds/$LOCALE/alphabet/%s", str1);
-    second_operand_str = g_strdup_printf("sounds/$LOCALE/alphabet/%s", str2);
+    first_operand_str = g_strdup_printf("voices/$LOCALE/alphabet/%s", str1);
+    second_operand_str = g_strdup_printf("voices/$LOCALE/alphabet/%s", str2);
 
-    gc_sound_play_ogg(first_operand_str, audioOperand , second_operand_str, "sounds/$LOCALE/misc/equal.ogg", NULL);
+    gc_sound_play_ogg(first_operand_str, audioOperand , second_operand_str, "voices/$LOCALE/misc/equal.ogg", NULL);
 
     g_free(str1);
     g_free(str2);
