@@ -4,7 +4,7 @@
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <stdarg.h>
@@ -196,7 +195,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       extern gchar *exec_prefix;
       gnuchess_bin = g_build_filename( exec_prefix, "bin", "gnuchess", NULL);
       if (!g_file_test (gnuchess_bin, G_FILE_TEST_EXISTS)) {
-	gc_dialog(_("Error: The external program gnuchess is required\nto play chess in gcompris.\n"
+	gc_dialog(_("Error: The external program gnuchess is required\nto play chess in GCompris.\n"
 		    "Find this program on http://www.rpmfind.net or in your\nGNU/Linux distribution\n"
 		    "And check it is located here: "GNUCHESS),
 		  gc_board_stop);
