@@ -4,7 +4,7 @@
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <glib.h>
@@ -154,7 +153,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
   ready = sounds_are_fine();
 
-  gc_sound_pause();
+  gc_sound_bg_pause();
 
   if (agcomprisBoard!=NULL)
     {
@@ -197,7 +196,7 @@ static void end_board ()
     }
   gc_locale_reset();
   gcomprisBoard = NULL;
-  gc_sound_resume();
+  gc_sound_bg_resume();
 }
 
 /* ======================================= */
@@ -237,7 +236,7 @@ static void repeat ()
 
       str1 = gc_sound_alphabet(right_letter);
 
-      right_letter_ogg = g_strdup_printf("sounds/$LOCALE/alphabet/%s", str1);
+      right_letter_ogg = g_strdup_printf("voices/$LOCALE/alphabet/%s", str1);
       g_free(str1);
 
       if(right_letter_ogg) {
@@ -269,7 +268,7 @@ static gboolean sounds_are_fine()
   letter_str = gc_sound_alphabet(letter);
   g_free(letter);
 
-  str2 = gc_file_find_absolute("sounds/$LOCALE/alphabet/%s", letter_str);
+  str2 = gc_file_find_absolute("voices/$LOCALE/alphabet/%s", letter_str);
 
   if (!str2)
     {
@@ -283,7 +282,7 @@ static gboolean sounds_are_fine()
 
       if (!str2)
 	{
-	  gchar *msg = g_strdup_printf( _("Error: this activity requires that you first install\nthe packages with gcompris voices for the locale '%s' or '%s'"),
+	  gchar *msg = g_strdup_printf( _("Error: this activity requires that you first install\nthe packages with GCompris voices for the locale '%s' or '%s'"),
 					locale, "en");
 	  gc_dialog(msg, gc_board_stop);
 	  g_free(msg);
@@ -323,7 +322,7 @@ click_on_letter_next_level()
   gc_score_set(gcomprisBoard->sublevel);
   g_free (right_letter);
   /* Try the next level */
-  gc_sound_play_ogg("sounds/$LOCALE/misc/click_on_letter.ogg", NULL);
+  gc_sound_play_ogg("voices/$LOCALE/misc/click_on_letter.ogg", NULL);
   click_on_letter_create_item(gnome_canvas_root(gcomprisBoard->canvas));
 }
 /* ==================================== */
@@ -634,7 +633,7 @@ config_start(GcomprisBoard *agcomprisBoard,
   gchar *saved_locale_sound = g_hash_table_lookup( config, "locale_sound");
 
   gc_board_config_combo_locales_asset( "Select sound locale", saved_locale_sound,
-				"sounds/$LOCALE/colors/purple.ogg");
+				"voices/$LOCALE/colors/purple.ogg");
 
   gboolean up_init = FALSE;
 
