@@ -1,12 +1,12 @@
 /* gcompris - gletters.c
  *
- * Time-stamp: <2007-04-15 21:15:19 bruno>
+ * Time-stamp: <2007-08-22 01:27:16 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <string.h>
@@ -635,7 +634,7 @@ static GnomeCanvasItem *gletters_create_item(GnomeCanvasGroup *parent)
       gchar *str2 = NULL;
       gchar *letter_unichar_name = gc_sound_alphabet(letter);
 
-      str2 = g_strdup_printf("sounds/$LOCALE/alphabet/%s", letter_unichar_name);
+      str2 = g_strdup_printf("voices/$LOCALE/alphabet/%s", letter_unichar_name);
 
       gc_sound_play_ogg(str2, NULL);
 
