@@ -1,12 +1,12 @@
 /* gcompris - shapegame.c
  *
- * Time-stamp: <2006/08/21 23:35:01 bruno>
+ * Time-stamp: <2007-08-22 01:25:02 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /* libxml includes */
@@ -103,11 +102,9 @@ struct _ShapeBox {
 };
 static ShapeBox shapeBox;
 
-#define BUTTON_SPACE		40
-
 /* Hash table of all the shapes in the list of shapes (one by different pixmap plus icon list) */
 static GHashTable *shapelist_table = NULL;
-static gint SHAPE_BOX_WIDTH_RATIO = 18;
+static gint SHAPE_BOX_WIDTH = 44;
 
 static GnomeCanvasItem	*shape_root_item;
 static GnomeCanvasItem	*shape_list_root_item;
@@ -115,7 +112,6 @@ static GnomeCanvasItem	*shape_list_root_item;
 /* The tooltip */
 static GnomeCanvasGroup	*tooltip_root_item;
 static GnomeCanvasItem	*tooltip_text_item;
-static GnomeCanvasItem	*tooltip_text_item_s;
 static GnomeCanvasItem	*tooltip_bg_item;
 
 static void		 start_board (GcomprisBoard *agcomprisBoard);
@@ -551,7 +547,7 @@ static void shapegame_init_canvas(GnomeCanvasGroup *parent)
   shape_root_item = \
     gnome_canvas_item_new (parent,
 			   gnome_canvas_group_get_type (),
-			   "x", (double)gcomprisBoard->width/SHAPE_BOX_WIDTH_RATIO,
+			   "x", (double)SHAPE_BOX_WIDTH,
 			   "y", (double)0,
 			   NULL);
 
@@ -564,7 +560,7 @@ static void shapegame_init_canvas(GnomeCanvasGroup *parent)
 					 );
 
   /* Create the tooltip area */
-  pixmap = gc_skin_pixmap_load("button_large.png");
+  pixmap = gc_skin_pixmap_load("button_large3.png");
   tooltip_bg_item = \
     gnome_canvas_item_new (GNOME_CANVAS_GROUP(tooltip_root_item),
 			   gnome_canvas_pixbuf_get_type (),
@@ -574,17 +570,6 @@ static void shapegame_init_canvas(GnomeCanvasGroup *parent)
 			   NULL);
   gdk_pixbuf_unref(pixmap);
 
-  tooltip_text_item_s = \
-    gnome_canvas_item_new (GNOME_CANVAS_GROUP(tooltip_root_item),
-			   gnome_canvas_text_get_type (),
-			   "text", "",
-			   "font", gc_skin_font_board_small,
-			   "x", (double)gdk_pixbuf_get_width(pixmap)/2 + 1.0,
-			   "y", 24.0 + 1.0,
-			   "anchor", GTK_ANCHOR_CENTER,
-			   "justification", GTK_JUSTIFY_CENTER,
-			   "fill_color_rgba", gc_skin_color_shadow,
-			   NULL);
   tooltip_text_item = \
     gnome_canvas_item_new (GNOME_CANVAS_GROUP(tooltip_root_item),
 			   gnome_canvas_text_get_type (),
@@ -757,7 +742,7 @@ add_shape_to_list_of_shapes(Shape *shape)
             gdk_pixbuf_unref(scale);
 
             // add the hand
-            hand = gc_skin_pixmap_load("boardicons/leftright.png");
+            hand = gc_skin_pixmap_load("boardicons/leftright.svg");
             h = ICON_HEIGHT/3;
             w = gdk_pixbuf_get_width(hand) * h / gdk_pixbuf_get_height(hand);
             scale = gdk_pixbuf_scale_simple(hand, w, h, GDK_INTERP_BILINEAR);
@@ -824,7 +809,7 @@ static Shape *find_closest_shape(double x, double y, double limit)
     if(shape->type==SHAPE_TARGET)
       {
 	/* Calc the distance between this shape and the given coord */
-	dist = sqrt(pow((shape->x-x),2) + pow((shape->y-y),2));
+	dist = sqrt(pow((shape->x-x+SHAPE_BOX_WIDTH),2) + pow((shape->y-y),2));
 	if(dist<goodDist)
 	  {
 	    goodDist=dist;
@@ -935,7 +920,6 @@ static gint item_event_drag(GnomeCanvasItem *item, GdkEvent *event, gpointer dat
     switch(event->type)
     {
         case GDK_BUTTON_PRESS:
-	    gc_sound_play_ogg ("sounds/bleep.wav", NULL);
             switch(shape -> type)
             {
                 case SHAPE_ICON:
@@ -958,8 +942,11 @@ static gint item_event_drag(GnomeCanvasItem *item, GdkEvent *event, gpointer dat
 
                         gc_sound_play_ogg(soundfile, NULL);
                     }
+		    else
+		      gc_sound_play_ogg ("sounds/bleep.wav", NULL);
                     break;
                 case SHAPE_TARGET:
+		    gc_sound_play_ogg ("sounds/bleep.wav", NULL);
                     gnome_canvas_item_hide(shape->item);
 
                     // unplace this shape
@@ -1095,11 +1082,8 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 	 gnome_canvas_item_set(GNOME_CANVAS_ITEM(tooltip_bg_item),
 			       "y", 0.0,
 			       NULL);
-	 gnome_canvas_item_set(GNOME_CANVAS_ITEM(tooltip_text_item_s),
-			       "text", shape->tooltip,
-			       NULL);
 	 gnome_canvas_item_set(GNOME_CANVAS_ITEM(tooltip_text_item),
-			       "text", shape->tooltip,
+			       "text", gettext(shape->tooltip),
 			       NULL);
 	 gnome_canvas_item_show(GNOME_CANVAS_ITEM(tooltip_root_item));
        }
