@@ -1,12 +1,12 @@
 /* gcompris - wordsgame.c
  *
- * Time-stamp: <2007-04-15 21:17:08 bruno>
+ * Time-stamp: <2007-08-22 01:27:15 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <string.h>
@@ -180,7 +179,8 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       /* disable im_context */
       //gcomprisBoard->disable_im_context = TRUE;
 
-      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "opt/scenery_background.png");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+			"opt/scenery_background.png");
 
 
       gcomprisBoard->level = 1;
@@ -263,6 +263,7 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
     return TRUE;
   }
 
+
   if (preedit_str){
     g_warning("preedit_str %s", preedit_str);
     /* show the preedit string on bottom of the window */
@@ -344,9 +345,9 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 	    tmpstr = g_utf8_strndup(item_on_focus->word,
 				    item_on_focus->count);
 	    /* Add the ZERO WIDTH JOINER to force joined char in Arabic and Hangul
-	     *  http://en.wikipedia.org/wiki/Zero-width_joiner
+	     *  http://en.wikipedia.org/wiki/Zero-width_joiner (UTF-8: e2808d)
 	     */
-	    item_on_focus->overword = g_strdup_printf("%s%lc", tmpstr, 0x200D);
+	    item_on_focus->overword = g_strdup_printf("%s%c%c%c", tmpstr, 0xe2, 0x80, 0x8d);
 	    g_free(tmpstr);
 	    gnome_canvas_item_set (item_on_focus->overwriteItem,
 				   "text", item_on_focus->overword,
