@@ -1,12 +1,12 @@
 /* gcompris - config.c
  *
- * Time-stamp: <2006/08/21 23:28:06 bruno>
+ * Time-stamp: <2007-08-22 01:21:16 bruno>
  *
  * Copyright (C) 2000-2003 Bruno Coudoin
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /**
@@ -57,11 +56,13 @@ static gboolean is_displayed			= FALSE;
 
 static gchar *linguas[] = {
   "",			N_("Your system default"),
+  "af_ZA.UTF-8", 	N_("Afrikaans"),
   "am_ET.UTF-8", 	N_("Amharic"),
   "ar_AE.UTF-8", 	N_("Arabic"),
   "ar_TN.UTF-8", 	N_("Arabic (Tunisia)"),
   "az_AZ.UTF-8", 	N_("Turkish (Azerbaijan)"),
   "bg_BG.UTF-8",	N_("Bulgarian"),
+  "br_FR.UTF-8",	N_("Breton"),
   "ca_ES.UTF-8",	N_("Catalan"),
   "cs_CZ.UTF-8",	N_("Czech Republic"),
   "da_DK.UTF-8", 	N_("Danish"),
@@ -129,7 +130,7 @@ static gchar *timername[] = {
 
 static gchar *screenname[] = {
   "640x480",
-  N_("800x600 (Default for gcompris)"),
+  N_("800x600 (Default for GCompris)"),
   "1024x768",
 };
 
@@ -751,10 +752,10 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	  else
 	    {
 	      if(!properties->music)
-		sdlplayer_halt_music();
+		gc_sound_bg_close();
 
 	      if(!properties->fx)
-		sdlplayer_halt_fx();
+		gc_sound_fx_close();
 	    }
 	  gc_prop_save(properties);
 	}
@@ -786,12 +787,11 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 				 NULL);
 	  if(!properties->music)
 	    {
-	      sdlplayer_halt_music();
+	      gc_sound_bg_close();
 	    }
 	  else
 	    {
-	      gc_sound_init();
-	      sdlplayer_resume_music();
+	      gc_sound_bg_reopen();
 	    }
 	}
       else if(!strcmp((char *)data, "effect"))
