@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <signal.h>
@@ -134,19 +133,19 @@ static gchar *popt_drag_mode       = NULL;
 
 static GOptionEntry options[] = {
   {"fullscreen", 'f', 0, G_OPTION_ARG_NONE, &popt_fullscreen,
-   N_("run gcompris in fullscreen mode."), NULL},
+   N_("run GCompris in fullscreen mode."), NULL},
 
   {"window", 'w', 0, G_OPTION_ARG_NONE, &popt_window,
-   N_("run gcompris in window mode."), NULL},
+   N_("run GCompris in window mode."), NULL},
 
   {"sound", 's', 0, G_OPTION_ARG_NONE, &popt_sound,
-   N_("run gcompris with sound enabled."), NULL},
+   N_("run GCompris with sound enabled."), NULL},
 
   {"mute", 'm', 0, G_OPTION_ARG_NONE, &popt_mute,
-   N_("run gcompris without sound."), NULL},
+   N_("run GCompris without sound."), NULL},
 
   {"cursor", 'c', 0, G_OPTION_ARG_NONE, &popt_cursor,
-   N_("run gcompris with the default gnome cursor."), NULL},
+   N_("run GCompris with the default gnome cursor."), NULL},
 
   {"difficulty", 'd', 0, G_OPTION_ARG_INT, &popt_difficulty_filter,
    N_("display only activities with this difficulty level."), NULL},
@@ -164,7 +163,9 @@ static GOptionEntry options[] = {
    N_("Disable XF86VidMode (No screen resolution change)."), NULL},
 
   {"root-menu", 'l', 0, G_OPTION_ARG_STRING, &popt_root_menu,
-   N_("Run gcompris with local menu (e.g -l /reading will let you play only activities in the reading directory, -l /strategy/connect4 only the connect4 activity)"), NULL},
+   N_("Run GCompris with local menu"
+      " (e.g -l /reading will let you play only activities in the reading directory, -l /strategy/connect4 only the connect4 activity)."
+      " Use '-l list' to list all the availaible activities and their descriptions."), NULL},
 
   {"local-activity", 'L', 0, G_OPTION_ARG_STRING, &popt_local_activity,
    N_("Run GCompris with local activity directory added to menu"), NULL},
@@ -969,14 +970,28 @@ void gc_fullscreen_set(gboolean state)
     {
       gdk_window_set_decorations (window->window, 0);
       gdk_window_set_functions (window->window, 0);
+      gtk_widget_set_uposition (window, 0, 0);
 #ifdef XF86_VIDMODE
-      if(properties->noxf86vm)
+      if(!properties->noxf86vm)
+      {
+	gdk_window_set_override_redirect (window->window, 1);
+        gdk_window_set_keep_above (window->window, 1);
+        gdk_window_raise (window->window);
+	gdk_window_focus (window->window, GDK_CURRENT_TIME);
+      }
+      else
 #endif
 	gtk_window_fullscreen (GTK_WINDOW(window));
-      gtk_widget_set_uposition (window, 0, 0);
     }
   else
     {
+#ifdef XF86_VIDMODE
+      if(!properties->noxf86vm)
+      {
+        gdk_window_set_keep_above (window->window, 0);
+	gdk_window_set_override_redirect (window->window, 0);
+      }
+#endif
       /* The hide must be done at least for KDE */
       gtk_widget_hide (window);
       gdk_window_set_decorations (window->window, GDK_DECOR_ALL);
@@ -986,7 +1001,6 @@ void gc_fullscreen_set(gboolean state)
       if(properties->noxf86vm)
 #endif
 	gtk_window_unfullscreen (GTK_WINDOW(window));
-      gtk_widget_set_uposition (window, 0, 0);
 
       /* Mandatory or on windows we get iconified */
       gtk_window_deiconify (GTK_WINDOW(window));
@@ -1074,7 +1088,7 @@ static void quit_cb (GtkWidget *widget, gpointer data)
 void gc_terminate(int signum)
 {
 
-  g_warning("gcompris got the %d signal, starting exit procedure", signum);
+  g_warning("GCompris got the %d signal, starting exit procedure", signum);
 
   gc_exit();
 
@@ -1397,6 +1411,58 @@ static gint xf86_focus_changed(GtkWindow *window,
 
 #endif
 
+static void
+start_bg_music (gchar *file)
+{
+  g_warning ("start_bg_music %s", file);
+  gc_sound_bg_reopen();
+}
+
+/* Single instance Check */
+static void
+single_instance_check()
+{
+  lock_file = g_strdup_printf("%s/%s", properties->config_dir, GC_LOCK_FILE);
+  if(!popt_nolockcheck)
+    {
+      GTimeVal current_time;
+      g_get_current_time(&current_time);
+
+      if (g_file_test (lock_file, G_FILE_TEST_EXISTS))
+	{
+	  char *result;
+	  gsize length;
+	  glong seconds;
+	  /* Read it's content */
+	  g_file_get_contents(lock_file,
+			      &result,
+			      &length,
+			      NULL);
+	  sscanf(result, "%ld", &seconds);
+
+	  if(current_time.tv_sec - seconds < GC_LOCK_LIMIT)
+	    {
+	      printf(_("GCompris won't start because the lock file is less than %d seconds old.\n"),
+		     GC_LOCK_LIMIT);
+	      printf(_("The lock file is: %s\n"),
+		     lock_file);
+	      exit(0);
+	    }
+	}
+
+      {
+	/* Update the date in it (in seconds) */
+	char date_str[64];
+	sprintf(date_str, "%ld", current_time.tv_sec);
+	g_file_set_contents(lock_file,
+			    date_str,
+			    strlen(date_str),
+			    NULL);
+      }
+    }
+  g_free(lock_file);
+}
+
 /*****************************************
  * Main
  *
@@ -1489,41 +1555,6 @@ main (int argc, char *argv[])
   */
   gc_prop_load(properties, GC_PROP_FROM_SYSTEM_CONF);
 
-  /* Single instance Check */
-  lock_file = g_strdup_printf("%s/%s", properties->config_dir, GC_LOCK_FILE);
-  if(!popt_nolockcheck)
-    {
-      GTimeVal current_time;
-      g_get_current_time(&current_time);
-
-      if (g_file_test (lock_file, G_FILE_TEST_EXISTS))
-	{
-	  char *result;
-	  gsize length;
-	  glong seconds;
-	  /* Read it's content */
-	  g_file_get_contents(lock_file,
-			      &result,
-			      &length,
-			      NULL);
-	  sscanf(result, "%ld", &seconds);
-
-	  if(current_time.tv_sec - seconds < GC_LOCK_LIMIT)
-	    exit(0);
-	}
-
-      {
-	/* Update the date in it (in seconds) */
-	char date_str[64];
-	sprintf(date_str, "%ld", current_time.tv_sec);
-	g_file_set_contents(lock_file,
-			    date_str,
-			    strlen(date_str),
-			    NULL);
-      }
-    }
-
-
   /* Set the locale */
 #if defined WIN32
   gc_user_default_locale = g_win32_getlocale();
@@ -1629,7 +1660,7 @@ main (int argc, char *argv[])
       printf(_("The list of available activities is :\n"));
 
       gc_db_init();
-
+      gc_board_init();
       gc_menu_load();
 
       GList *list = NULL;
@@ -1836,6 +1867,8 @@ main (int argc, char *argv[])
 
   /*------------------------------------------------------------*/
 
+  single_instance_check();
+
   gc_skin_load(properties->skin);
 
   if(properties->music || properties->fx)
@@ -1852,21 +1885,36 @@ main (int argc, char *argv[])
 
   setup_window ();
 
+  gtk_widget_show_all (window);
+
   if (properties->fullscreen)
     gc_fullscreen_set(properties->fullscreen);
 
-  gtk_widget_show_all (window);
-
   /* If a specific activity is selected, skeep the intro music */
   if(!popt_root_menu)
     {
       if (properties->music)
-	gc_sound_play_ogg("music/intro.ogg", "sounds/$LOCALE/misc/welcome.ogg", NULL);
+	{
+	  gc_sound_play_ogg("music/intro.ogg",
+			    NULL);
+	  gc_sound_play_ogg_cb("voices/$LOCALE/misc/welcome.ogg",
+			       start_bg_music);
+	}
       else
-	gc_sound_play_ogg("sounds/$LOCALE/misc/welcome.ogg", NULL);
+	gc_sound_play_ogg("voices/$LOCALE/misc/welcome.ogg", NULL);
     }
 
   gtk_main ();
 
+  /* FIXME: HACK Needed or we have unresolved symbols at python plugin dlopen
+   *        Is there a better way to fix these?
+   */
+  GnomeCanvasItem *dummy = NULL;
+  GNOME_IS_CANVAS_POLYGON(dummy);
+  GNOME_IS_CANVAS_CLIPGROUP(dummy);
+  GNOME_IS_CANVAS_BPATH(dummy);
+  GType type = GNOME_TYPE_CANVAS_POLYGON;
+  type = type;
+
   return(0);
 }
